@@ -23,15 +23,15 @@
 
 import requests
 from lxml import html
-import os,re
+import os
+import re
 import argparse
 
 parser = argparse.ArgumentParser()
 parser.add_argument("url", help="url to analize broken links")
 args = parser.parse_args()
-print(args.url)
 
-start_url = args.url+'/'
+start_url = args.url + '/'
 response = requests.get(start_url)
 tree = html.fromstring(response.text)
 imgs = tree.cssselect('img')  # or tree.xpath('//a')
@@ -59,17 +59,15 @@ for i in absoluteurls:
     if (r.status_code != 200):
         buggyurls.append(i)
 
-        
 nbuggyurls = len(buggyurls)
 if (nbuggyurls == 1):
     print("%s images with troubles:" % str(nbuggyurls))
 else:
-    print("%s images with troubles:" % str(nbuggyurls))    
+    print("%s images with troubles:" % str(nbuggyurls))
 
 print(buggyurls)
-nurls = len(imgs) - len(buggyurls) 
+nurls = len(imgs) - len(buggyurls)
 if (nurls == 1):
     print(str(nurls) + " good images")
 else:
-    print(str(nurls) + " good images")    
-
+    print(str(nurls) + " good images")
