@@ -25,7 +25,8 @@
 
 import requests
 from lxml import html
-import os,re
+import os
+import re
 import xml.etree.ElementTree as ET
 import argparse
 import requests
@@ -38,17 +39,16 @@ args = parser.parse_args()
 
 r = requests.get(args.url)
 fo = open("/tmp/rss.xml", "w")
-fo.write(r.text);
+fo.write(r.text)
 fo.close()
 
 tree = ET.parse('/tmp/rss.xml')
 root = tree.getroot()
 
 for elem in tree.iter():
-
     if (elem.tag == "title"):
-        print("----------------------------------------------------------------------")
+        print("----------------------------------------------------")
         print(elem.text)
     if (elem.tag == "link"):
         print(elem.text)
-        print("----------------------------------------------------------------------")
+        print("----------------------------------------------------")
