@@ -29,13 +29,23 @@ else
     echo "dameurls.py with davidam.com test is ok"
 fi
 
-python3 dameimgs.py http://www.damegender.net > damewebutils/files/tests/damegender-imgs-$(date "+%Y-%m-%d-%H").txt
+
+python3 dameimgs.py http://damegender.davidam.com > damewebutils/files/tests/damegender-imgs-$(date "+%Y-%m-%d-%H").txt
 
 if ! cmp damewebutils/files/tests/damegender-imgs.txt damewebutils/files/tests/damegender-imgs-$(date "+%Y-%m-%d-%H").txt >/dev/null 2>&1
 then
-    echo "dameimgs.py with damegender.net test is failing"
+    echo "dameimgs.py with damegender.davidam.com test is failing"
 else
-    echo "dameimgs.py with damegender.net test is ok"
+    echo "dameimgs.py with damegender.davidam.com test is ok"
+fi
+
+python3 damerss.py http://damegender.davidam.com/rss-feed.xml | head -n 5 > damewebutils/files/tests/damegender-rss-$(date "+%Y-%m-%d-%H").txt
+
+if ! cmp damewebutils/files/tests/damegender-rss.txt damewebutils/files/tests/damegender-rss-$(date "+%Y-%m-%d-%H").txt >/dev/null 2>&1 
+then 
+    echo "damerss.py with damegender.davidam.com test is failing"
+else
+    echo "damerss.py with damegender.davidam.com test is ok"
 fi
 
 python3 template.py > damewebutils/files/tests/template-$(date "+%Y-%m-%d-%H").txt
